==> pyhttpclient-0.1.0.tar.gz: pyhttpclient-0.1.0/http/__init__.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
import urllib2
import urllib
from StringIO import StringIO
import gzip
import json


def read_and_log(r):
    s = r.read()
    encoding = r.info().get('Content-Encoding')
    if encoding and 'gzip' in encoding:
        buf = StringIO(s)
        f = gzip.GzipFile(fileobj=buf)
        s = f.read()
    # print r.url,s
    return s


def put(url, data=None, headers=None):
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    request = urllib2.Request(url, data=(data and urllib.urlencode(data) or ''))
    request.get_method = lambda: 'PUT'
    return read_and_log(opener.open(request))


def delete(url, data=None, headers=None):
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    request = urllib2.Request(url,
                              data=(data and urllib.urlencode(data) or ''))
    request.get_method = lambda: 'DELETE'
    return read_and_log(opener.open(request))


def post(url, query=None, data=None, headers=None, dataGzip=False, dataJson=False):
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    query = query and urllib.urlencode(query) or ''
    if isinstance(data, dict):
        if dataJson:
            data = json.dumps(data)
            if not headers: headers = {}
            headers['Content-Type'] = 'application/json'
        else:
            data = urllib.urlencode(data)
    elif isinstance(data, str):
        if not headers: headers = {}
        headers['Content-Type'] = 'application/json'

    if dataGzip:
        if not headers: headers = {}
        headers['Content-Encoding'] = 'gzip'
        out = StringIO()
        with gzip.GzipFile(fileobj=out, mode="w") as f:
            f.write(data)
        data = out.getvalue()
    request = urllib2.Request('%s?%s' % (url, query), data=data,
                              headers=headers and headers or {})
    request.get_method = lambda: 'POST'
    return read_and_log(opener.open(request))


def get(url, data=None, headers=None, dataGzip=False):
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    data = data and urllib.urlencode(data) or ''
    url = '%s?%s' % (url, data)
    if dataGzip:
        if not headers:
            headers = {}
        headers['Accept-Encoding'] = 'gzip'
    request = urllib2.Request(url,
                              headers=headers and headers or {})
    return read_and_log(opener.open(request))


# def upload(url, filename, fileParam='file', query=None, data=None, headers=None):
#     import MultipartPostHandler
#     import cookielib
#     cookies = cookielib.CookieJar()
#     opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cookies),
#                                   MultipartPostHandler.MultipartPostHandler)
#     query = query and urllib.urlencode(query) or ''
#     data = {'x': 'x', fileParam: open(filename, "rb")}
#     return read_and_log(opener.open('%s?%s' % (url, query), data))

==> pyhttpclient-0.1.1.tar.gz: pyhttpclient-0.1.1/http/__init__.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
import urllib2
import urllib
from StringIO import StringIO
import gzip
import json


def read_and_log(r):
    s = r.read()
    encoding = r.info().get('Content-Encoding')
    if encoding and 'gzip' in encoding:
        buf = StringIO(s)
        f = gzip.GzipFile(fileobj=buf)
        s = f.read()
    # print r.url,s
    return s


def put(url, data=None, headers=None, timeout=object()):
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    request = urllib2.Request(url,
                              data=(data and urllib.urlencode(data) or ''),
                              headers=headers and headers or {})
    request.get_method = lambda: 'PUT'
    return read_and_log(opener.open(request, timeout=timeout))


def delete(url, data=None, headers=None, timeout=object()):
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    request = urllib2.Request(url,
                              data=(data and urllib.urlencode(data) or ''),
                              headers=headers and headers or {})
    request.get_method = lambda: 'DELETE'
    return read_and_log(opener.open(request, timeout=timeout))


def post(url, query=None, data=None, headers=None, timeout=object(), dataGzip=False, dataJson=False):
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    query = query and urllib.urlencode(query) or ''
    if isinstance(data, dict):
        if dataJson:
            data = json.dumps(data)
            if not headers: headers = {}
            headers['Content-Type'] = 'application/json'
        else:
            data = urllib.urlencode(data)
    elif isinstance(data, str):
        if not headers: headers = {}
        headers['Content-Type'] = 'application/json'

    if dataGzip:
        if not headers: headers = {}
        headers['Content-Encoding'] = 'gzip'
        out = StringIO()
        with gzip.GzipFile(fileobj=out, mode="w") as f:
            f.write(data)
        data = out.getvalue()
    request = urllib2.Request('%s?%s' % (url, query), data=data,
                              headers=headers and headers or {})
    request.get_method = lambda: 'POST'
    return read_and_log(opener.open(request, timeout=timeout))


def get(url, data=None, headers=None, timeout=object(), dataGzip=False):
    opener = urllib2.build_opener(urllib2.HTTPHandler)
    data = data and urllib.urlencode(data) or ''
    url = '%s?%s' % (url, data)
    if dataGzip:
        if not headers:
            headers = {}
        headers['Accept-Encoding'] = 'gzip'
    request = urllib2.Request(url,
                              headers=headers and headers or {})
    return read_and_log(opener.open(request, timeout=timeout))


# def upload(url, filename, fileParam='file', query=None, data=None, headers=None):
#     import MultipartPostHandler
#     import cookielib
#     cookies = cookielib.CookieJar()
#     opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cookies),
#                                   MultipartPostHandler.MultipartPostHandler)
#     query = query and urllib.urlencode(query) or ''
#     data = {'x': 'x', fileParam: open(filename, "rb")}
#     return read_and_log(opener.open('%s?%s' % (url, query), data))

if __name__ == '__main__':
    # print get('http://www.notexistised.com')
    print get('http://www.notexistised.com', timeout=1)
